@@ -32,6 +32,7 @@ namespace pybind11
 {
     namespace detail
     {
+#ifdef PYBIND11_DESCR // The macro is removed from pybind11 since 2.3
         template <class T, std::size_t N, xt::layout_type L>
         struct handle_type_name<xt::pytensor<T, N, L>>
         {
@@ -40,6 +41,7 @@ namespace pybind11
                 return _("numpy.ndarray[") + npy_format_descriptor<T>::name() + _("]");
             }
         };
+#endif
 
         template <class T, std::size_t N, xt::layout_type L>
         struct pyobject_caster<xt::pytensor<T, N, L>>
@@ -65,7 +67,11 @@ namespace pybind11
                 return src.inc_ref();
             }
 
+#ifdef PYBIND11_DESCR // The macro is removed from pybind11 since 2.3
             PYBIND11_TYPE_CASTER(type, handle_type_name<type>::name());
+#else
+            PYBIND11_TYPE_CASTER(type, _("numpy.ndarray[") + npy_format_descriptor<T>::name + _("]"));
+#endif
         };
 
         // Type caster for casting ndarray to xexpression<pytensor>
